@@ -444,7 +444,7 @@ static int PrecSetupBD(N_Vector cc, N_Vector cscale, N_Vector fval,
       for (j = 0; j < NUM_SPECIES; j++)
       {
         csave = cxy[j]; /* Save the j,jx,jy element of cc */
-        r     = MAX(sqruround * fabs(csave), r0 / scxy[j]);
+        r     = MAX(sqruround * SUNRabs(csave), r0 / scxy[j]);
         cxy[j] += r; /* Perturb the j,jx,jy element of cc */
         fac = ONE / r;
 
